Module: SidekiqAsyncTask

Defined in:
lib/sidekiq_async_task/async_task.rb,
lib/sidekiq_async_task/version.rb,
lib/sidekiq_async_task/async_job_scheduler.rb,
lib/sidekiq_async_task/transaction_support.rb,
lib/generators/sidekiq_async_task/install_generator.rb

Overview

Wrapper around sidekiq to make job scheduling transactional. Provides wrapper methods - perform_with_transaction_in and perform_with_transaction_async over perform_in and perform_async methods defined by sidekiq Creates a model named AsyncTask to store details about the job like, job_id, status, retry counts etc. When the transaction (inside which job is scheduled) is successfull, the task is schedules as a sidekiq job But in case of an exception, when Rollback is encountered, it doesn’t schedule the job.

Defined Under Namespace

Modules: AsyncJobScheduler Classes: AsyncTask, InstallGenerator, TransactionSupport

Constant Summary collapse

VERSION =
"1.0.0"